@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-def build_ext():
+def build_ext(name="test_ext"):
     import sys
     sys.path.append("..")
     from setup import get_config_schema
@@ -22,11 +22,12 @@ def build_ext():
     libs = conf["BOOST_PYTHON_LIBNAME"]
 
     import os
-    cmd = ("c++ -g -fpic -shared %s %s %s test_ext.cpp -o test_ext.so"
+    cmd = ("c++ -g -fpic -shared %s %s %s %s.cpp -o %s.so"
             % (
                 " ".join("-I"+ip for ip in inc_paths),
                 " ".join("-L"+ip for ip in lib_paths),
                 " ".join("-l"+ip for ip in libs),
+                name, name,
                 ))
     print cmd
     os.system(cmd)
@@ -34,4 +35,5 @@ def build_ext():
 
 
 if __name__ == "__main__":
-    build_ext()
+    import sys
+    build_ext(*sys.argv[1:])
